@@ -3,7 +3,8 @@
 Copyright (C) 1986, 1987, 1988, 1989, 1990, 1991, 1992, 1993, 1994,
     1995, 1996, 1997, 1998, 1999, 2000, 2001, 2002, 2003, 2004, 2005,
     2006, 2007, 2008, 2009, 2010, 2011, 2012, 2013, 2014, 2015, 2016,
-    2017, 2018, 2019, 2020 Massachusetts Institute of Technology
+    2017, 2018, 2019, 2020, 2021, 2022 Massachusetts Institute of
+    Technology
 
 This file is part of MIT/GNU Scheme.
 
@@ -1327,12 +1328,14 @@ the user from the mailer."
   (newline port))
 
 (define (write-mime-message-body-1 b-start b-end subpart? port)
-  (if (not (and subpart? (ref-variable mail-abbreviate-mime b-start)))
-      (write-message-header-field
-       "Content-Type"
-       (string-append "text/plain; charset="
-                      (ref-variable mail-charset b-start))
-       port))
+  (let ((charset (ref-variable mail-charset b-start)))
+    (if (not (and subpart?
+		  (ref-variable mail-abbreviate-mime b-start)
+		  (string-ci=? "us-ascii" charset)))
+	(write-message-header-field
+	 "Content-Type"
+	 (string-append "text/plain; charset=" charset)
+	 port)))
   (if (or (any-non-printable-7bit-chars? b-start b-end)
 	  (any-lines-too-long? b-start b-end 76))
       (begin
